main.run_multiband_regression

mb_regression.main.run_multiband_regression()

Main function to run the multiband regression processing in a separate thread.

This function creates and starts a background thread that runs the process_loop. It also allows the regression loop to be stopped via the returned Event object.

Returns

Name Type Description
tuple[threading.Thread, threading.Event] A tuple containing: - threading.Thread: The thread object running the processing loop - threading.Event: Event object that can be .set() to stop the processing